@@ -10,7 +10,8 @@ __all__ = [
     "Otsu_tresholding",
     "read_plu_topography",
     "fill_gap",
-    "top_hat_flattening"
+    "top_hat_flattening",
+    "convert"
 ]
 
 
@@ -292,7 +293,7 @@ def poly2Dreco(x,y, c):
     return np.polynomial.polynomial.polygrid2d(x,y,c).T
 
 
-def analyse_morphologique(img_bin, img):
+def analyse_morphologique(img_bin, img=None):
 
     '''
     find the features in the image
@@ -320,18 +321,30 @@ def analyse_morphologique(img_bin, img):
     labeled_array, num_features = label(img_bin,[[0,1,0], [1,1,1], [0,1,0]])
 
     morpho = {}
+    
+    if img is None:
+        for i in range(1,np.max(labeled_array)+1):
+            x,y = np.where(labeled_array==i)
+            morpho[i] = [ int(np.mean(x)), 
+                          max(x)-min(x)+1, 
+                          int(np.mean(y)),
+                          max(y)-min(y)+1,
+                          np.sum(labeled_array==i)
+                        ]
+            df = pd.DataFrame.from_dict(morpho, orient='index',
+                               columns=['x','long_x', 'y','long_y', 'size'])
+    else:
+        for i in range(1,np.max(labeled_array)+1):
+            x,y = np.where(labeled_array==i)
+            morpho[i] = [ int(np.mean(x)), 
+                          max(x)-min(x)+1, 
+                          int(np.mean(y)),
+                          max(y)-min(y)+1,
+                          np.sum(labeled_array==i),
+                          height(i)]
 
-    for i in range(1,np.max(labeled_array)+1):
-        x,y = np.where(labeled_array==i)
-        morpho[i] = [ int(np.mean(x)), 
-                      max(x)-min(x)+1, 
-                      int(np.mean(y)),
-                      max(y)-min(y)+1,
-                      np.sum(labeled_array==i),
-                      height(i)]
-
-    df = pd.DataFrame.from_dict(morpho, orient='index',
-                           columns=['x','long_x', 'y','long_y', 'size', 'height'])
+        df = pd.DataFrame.from_dict(morpho, orient='index',
+                               columns=['x','long_x', 'y','long_y', 'size', 'height'])
 
     return df
 
